<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Pasirinkite programą</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Įdiegtos programos</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Tinkinta komanda</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Komandų eilutė, kurią vykdyti:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="78"/>
        <source>Application name:</source>
        <translation>Programos pavadinimas:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Komandų eilutėje gali būti naudojami šie specialūs kodai:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Atvaizduoja vieno failo pavadinimą&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Atvaizduoja kelių failų pavadinimus&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Atvaizduoja vieną failo URI&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Atvaizduoja kelis URI&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Po komandos įvykdymo, palikti terminalo langą atvertą</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="88"/>
        <source>Execute in terminal emulator</source>
        <translation>Vykdyti terminalo emuliatoriuje</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Nustatyti pasirinktą programą kaip numatytąjį veiksmą šiam failo tipui</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Redaguoti žymeles</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="49"/>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="54"/>
        <source>Location</source>
        <translation>Vieta</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="64"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Pridėti elementą</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="74"/>
        <source>&amp;Remove Item</source>
        <translation>Ša&amp;linti elementą</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="20"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Vilkite, norėdami pakeisti elementų tvarką</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Vykdyti failą</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="42"/>
        <source>&amp;Open</source>
        <translation>&amp;Atverti</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="55"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Vykdyti</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="65"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Vykdyti &amp;terminale</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="88"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="102"/>
        <source>Remember for next files of this kind</source>
        <translation>Prisiminti kitiems šio tipo failams</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Kelias:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Failo pavadinimas:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="85"/>
        <source>File type:</source>
        <translation>Failo tipas:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="42"/>
        <source>Destination:</source>
        <translation>Paskirties vieta:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="65"/>
        <source>Processing:</source>
        <translation>Vykdoma:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="78"/>
        <source>Preparing...</source>
        <translation>Ruošiama...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="85"/>
        <source>Progress:</source>
        <translation>Eiga:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="119"/>
        <source>Time remaining:</source>
        <translation>Liko laiko:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="99"/>
        <source>Files processed:</source>
        <translation>Apdorota failų:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Failo savybės</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Vieta:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="132"/>
        <source>File type:</source>
        <translation>Failo tipas:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="155"/>
        <source>MIME type:</source>
        <translation>MIME tipas:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="195"/>
        <source>File size:</source>
        <translation>Failo dydis:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="218"/>
        <source>On-disk size:</source>
        <translation>Dydis diske:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="241"/>
        <source>Last modified:</source>
        <translation>Paskutinis pakeitimas:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>Link target:</source>
        <translation>Nuorodos paskirtis:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="178"/>
        <source>Open With:</source>
        <translation>Atverti naudojant:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Paskutinė prieiga:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Sukurta:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Turi:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Emblema:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Pasirinkti emblemą</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Išvalyti emblemą</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="397"/>
        <source>Device Usage:</source>
        <translation>Įrenginio naudojimas:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Leidimai</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Nuosavybė</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="473"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Grupė:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="457"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Savininkas:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Prieigos valdymas</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Kiti:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Padaryti failą vykdomuoju</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Skaityti</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Rašyti</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Vykdyti</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Sticky</source>
        <translation>Lipnus</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetUID</source>
        <translation>Nustatyti UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="763"/>
        <source>SetGID</source>
        <translation>Nustatyti GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Išplėstinė veiksena</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Tinkinti</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Pasirinkite programą, kad atvertumėte „%1“ failus</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Aplanką</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Tuščią failą</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Nurodytas katalogas „%1“ yra neteisingas</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Įkeliama...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Nėra poaplankių&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Atverti naujoje kort&amp;elėje</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Atverti naujame lan&amp;ge</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Atverti termina&amp;le</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Kopijuoti čia</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Perkelti čia</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Sukurti simbolinę nuorodą čia</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Negalima tempti čia</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Nauja žymelė</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Atrodo, kad šis failas „%1“ yra darbalaukio įrašas.
Ką norėtumėte su juo daryti?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Atrodo, kad šis tekstinis failas „%1“ yra vykdomasis scenarijus.
Ką norėtumėte su juo daryti?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Šis failas „%1“ yra vykdomasis. Ar norite jį vykdyti?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="115"/>
        <source>Go Back</source>
        <translation>Grįžti</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Kairėn</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>Go Forward</source>
        <translation>Pirmyn</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="123"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Dešinėn</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="130"/>
        <source>Reload</source>
        <translation>Įkelti iš naujo</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="131"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Create Folder</source>
        <translation>Sukurti aplanką</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Icon View</source>
        <translation>Piktogramų rodinys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Thumbnail View</source>
        <translation>Miniatiūrų rodinys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Compact View</source>
        <translation>Glaustas rodinys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Detailed List View</source>
        <translation>Išsamaus sąrašo rodinys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Icon Sizes</source>
        <translation>Piktogramų dydžiai</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="186"/>
        <source>Size of big icons:</source>
        <translation>Didelių piktogramų dydis:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="193"/>
        <source>Size of small icons:</source>
        <translation>Mažų piktogramų dydis:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Size of thumbnails:</source>
        <translation>Miniatiūrų dydis:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="216"/>
        <source>Show Hidden</source>
        <translation>Rodyti paslėptus</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="228"/>
        <source>Show Thumbnails</source>
        <translation>Rodyti miniatiūras</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="233"/>
        <source>Show File Tooltips</source>
        <translation>Rodyti failų paaiškinimus</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="240"/>
        <source>Smooth Scrolling</source>
        <translation>Glotnus slinkimas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="255"/>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <location filename="../filedialog.cpp" line="1064"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <source>Please select a file</source>
        <translation>Pasirinkite failą</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="681"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 jau yra.
Ar norite jį pakeisti?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1026"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Kelio „%1“ nėra</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1040"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>„%1“ nėra katalogas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1050"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>„%1“ nėra failas</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1204"/>
        <location filename="../filedialog.cpp" line="1321"/>
        <source>&amp;Open</source>
        <translation>&amp;Atverti</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1207"/>
        <location filename="../filedialog.cpp" line="1329"/>
        <source>&amp;Save</source>
        <translation>Į&amp;rašyti</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1214"/>
        <source>All Files (*)</source>
        <translation>Visi failai (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>Atverti failą</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>Įrašyti failą</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> piks.</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Atverti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Atverti naudojant...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Many files</source>
        <translation>Daug failų</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="420"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Ar norite atverti šį %1 failą?</numerusform>
            <numerusform>Ar norite atverti šiuos %1 failus?</numerusform>
            <numerusform>Ar norite atverti šiuos %1 failų?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="181"/>
        <source>Other Applications</source>
        <translation>Kitas programas</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="188"/>
        <source>Create &amp;New</source>
        <translation>Sukurti &amp;naują</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="207"/>
        <source>&amp;Restore</source>
        <translation>&amp;Atkurti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="217"/>
        <source>Cut</source>
        <translation>Iškirpti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="225"/>
        <source>Paste</source>
        <translation>Įdėti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="229"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Perkelti į šiukšlinę</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="289"/>
        <source>Mount</source>
        <translation>Prijungti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="303"/>
        <source>Unmount</source>
        <translation>Atjungti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="317"/>
        <source>Eject</source>
        <translation>Išstumti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="338"/>
        <source>Extract to...</source>
        <translation>Išskleisti į...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="346"/>
        <source>Extract Here</source>
        <translation>Išskleisti čia</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Compress</source>
        <translation>Glaudinti</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="362"/>
        <source>Properties</source>
        <translation>Savybės</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="376"/>
        <source>Trust selected executables</source>
        <translation>Pasitikėti pažymėtais vykdomaisiais</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="377"/>
        <source>Trust this executable</source>
        <translation>Pasitikėti šiuo vykdomuoju</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="482"/>
        <source>Output</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Delete</source>
        <translation>&amp;Ištrinti</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Kai kurie failai negali būti perkelti į šiukšlinę, kadangi esama failų sistema nepalaiko šios operacijos.
Ar norite vietoj to, juos ištrinti?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Ar norite ištrinti pažymėtą failą?</numerusform>
            <numerusform>Ar norite ištrinti pažymėtus failus?</numerusform>
            <numerusform>Ar norite ištrinti pažymėtus failus?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Ar norite perkelti pažymėtą failą į šiukšlinę?</numerusform>
            <numerusform>Ar norite perkelti pažymėtus failus į šiukšlinę?</numerusform>
            <numerusform>Ar norite perkelti pažymėtus failus į šiukšlinę?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move Files</source>
        <translation>Perkelti failus</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Šie failai perkeliami į paskirties aplanką:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Kopijuoti failus</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Šie failai kopijuojami į paskirties aplanką:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Perkelti failus į šiukšlinę</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Šie failai perkeliami į šiukšlinę:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Ištrinti failus</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Ištrinami šie failai:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Sukurti simbolines nuorodas</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Šiems failams kuriamos simbolinės nuorodos:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Keisti atributus</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Keičiami šių failų atributai:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Atkurti į šiukšlinę perkeltus failus</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Šie failai atkuriami iš šiukšlinės:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>View folder content</source>
        <translation>Žiūrėti aplanko turinį</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>View and modify folder content</source>
        <translation>Žiūrėti ir keisti aplanko turinį</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="172"/>
        <source>Read</source>
        <translation>Skaityti</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="173"/>
        <source>Read and write</source>
        <translation>Skaityti ir rašyti</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="175"/>
        <source>Forbidden</source>
        <translation>Uždrausta</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="292"/>
        <source>Files of different types</source>
        <translation>Įvairių tipų failai</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="315"/>
        <location filename="../filepropsdialog.cpp" line="322"/>
        <location filename="../filepropsdialog.cpp" line="329"/>
        <source>N/A</source>
        <translation>–</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="333"/>
        <source>Multiple Files</source>
        <translation>Keli failai</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="410"/>
        <source>%p% used</source>
        <translation>Panaudota %p%</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="411"/>
        <source>%1 Free of %2</source>
        <translation>Laisva %1 iš %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="457"/>
        <source>no file</source>
        <translation>jokių failų</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="459"/>
        <source>one file</source>
        <translation>vienas failas</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="461"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln failas</numerusform>
            <numerusform>%Ln failai</numerusform>
            <numerusform>%Ln failų</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="495"/>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Select an icon</source>
        <translation>Pasirinkti piktogramą</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="497"/>
        <location filename="../filepropsdialog.cpp" line="542"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Paveikslai (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="648"/>
        <source>Apply changes</source>
        <translation>Taikyti pakeitimus</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="649"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Ar norite rekursyviai taikyti šiuos pakeitimus visiems failams ir poaplankiams?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>Norėdami ieškoti, turite pasirinkti bent vieną katalogą.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Pasirinkti aplanką</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="486"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Negalima kopijuoti katalogą į jį patį!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="537"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Nepavyksta sukurti nuorodą ne savoje failų sistemoje</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Išvalyti šiukšlinę</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>Sukurti &amp;naują</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>Į&amp;dėti</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="89"/>
        <source>Select &amp;All</source>
        <translation>&amp;Pažymėti viską</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>Sorting</source>
        <translation>Rikiavimas</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="105"/>
        <source>Show Hidden</source>
        <translation>Rodyti paslėptus</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="140"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Aplanko &amp;savybės</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>Output</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By File Name</source>
        <translation>Pagal failo pavadinimą</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Modification Time</source>
        <translation>Pagal pakeitimo laiką</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="207"/>
        <source>By Creation Time</source>
        <translation>Pagal sukūrimo laiką</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="210"/>
        <source>By Deletion Time</source>
        <translation>Pagal ištrynimo laiką</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Size</source>
        <translation>Pagal failo dydį</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Type</source>
        <translation>Pagal failo tipą</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Owner</source>
        <translation>Pagal failo savininką</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="216"/>
        <source>By File Group</source>
        <translation>Pagal failo grupę</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="222"/>
        <source>Ascending</source>
        <translation>Didėjančiai</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Descending</source>
        <translation>Mažėjančiai</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="244"/>
        <source>Folder First</source>
        <translation>Pirmiausia aplankai</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="252"/>
        <source>Hidden Last</source>
        <translation>Paslėptus rodyti paskiausiai</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="260"/>
        <source>Case Sensitive</source>
        <translation>Skirti raidžių dydį</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Vieta:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Failo tipas:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Failo dydis:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Paskutinis pakeitimas:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Paskutinė prieiga:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>–</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Sukurtas:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Savininkas:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Grupė:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Pakeista</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Sukurtas</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Ištrintas</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Savininkas</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Grupė</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="410"/>
        <source>Auto-resize columns</source>
        <translation>Automatiškai keisti stulpelių dydį</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="427"/>
        <source>Visible Columns</source>
        <translation>Matomi stulpeliai</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Pusjuodis</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursyvas</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Prijungti</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="123"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Taisyti kelią</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="126"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Kopijuoti kelią</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Vietos</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Darbalaukis</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Kompiuteris</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Programos</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Įrenginiai</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Žymelės</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Šiukšlinė</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="563"/>
        <source>Open in New Tab</source>
        <translation>Atverti naujoje kortelėje</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="567"/>
        <source>Open in New Window</source>
        <translation>Atverti naujame lange</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="580"/>
        <source>Empty Trash</source>
        <translation>Išvalyti šiukšlinę</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="600"/>
        <location filename="../placesview.cpp" line="662"/>
        <source>Hide</source>
        <translation>Slėpti</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="617"/>
        <source>Move Bookmark Up</source>
        <translation>Pakelti žymelę</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Move Bookmark Down</source>
        <translation>Nuleisti žymelę</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="629"/>
        <source>Rename Bookmark</source>
        <translation>Pervadinti žymelę</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <source>Remove Bookmark</source>
        <translation>Šalinti žymelę</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <location filename="../placesview.cpp" line="676"/>
        <source>Unmount</source>
        <translation>Atjungti</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="647"/>
        <source>Mount</source>
        <translation>Prijungti</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="653"/>
        <source>Eject</source>
        <translation>Išstumti</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="688"/>
        <source>Show All Entries</source>
        <translation>Rodyti visus įrašus</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tipas: %1
Dydis: %2
Pakeista: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tipas: %1
Pakeista: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="104"/>
        <source>&amp;Overwrite</source>
        <translation>Perraš&amp;yti</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="106"/>
        <source>&amp;Rename</source>
        <translation>Pe&amp;rvadinti</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="116"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Failas negali perrašyti pats save.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Pasirinkite kitokį pavadinimą.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Lists</source>
        <translation>Sąrašai</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Katalogų medis</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Nepavyksta iškelti failo „%s“ iš šiukšlinės: pradinis kelias nėra žinomas</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Prijungti</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Prisijungti &amp;anonimiškai</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Prisijungti kaip naudotoja&amp;s:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="76"/>
        <source>&amp;Username:</source>
        <translation>Na&amp;udotojo vardas:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="108"/>
        <source>&amp;Password:</source>
        <translation>Sla&amp;ptažodis:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="89"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Sritis:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Nedels&amp;iant užmiršti slaptažodį</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>Seanso trukmę nustato slaptažodžių tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>Prisiminti slaptažodį š&amp;iam seansui</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Prisiminti visam laik&amp;ui</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Pervadinti failą</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Įrašykite naują pavadinimą:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="674"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Sukurti aplanką</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Sukurti failą</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Įrašykite naują failo pavadinimą:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Naujas failas</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Įrašykite naują aplanko pavadinimą:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Naujas aplankas</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Įrašykite pavadinimą naujam %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="692"/>
        <source>Custom Icon Error</source>
        <translation>Tinkintos piktogramos klaida</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Kelias nėra prijungtas.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Neteisingas darbalaukio įrašo failas: „%1“</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Nėra nustatyta numatytoji programa, skirta paleisti „%1“</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Nepavyksta nustatyti darbinį katalogą į „%1“: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identifikatorius: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>–</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Patvirtinti failų pakeitimą</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Šioje vietoje jau yra failas tokiu pačiu pavadinimu.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Ar norite pakeisti esamą failą?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>with the following file?</source>
        <translation>šiuo failu?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Failo pavadinimas:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Taikyti šią parinktį visiems esamiems failams</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Ieškoti failų</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Pavadinimas/Vieta</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Failo pavadinimo šablonai:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Naudoti reguliarųjį reiškinį</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Vietos, kuriose ieškoti:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Pridėti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>Ša&amp;linti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Ieškoti paslėptų failų</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Failo tipas</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Ieškoti tik šių tipų failų:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Tekstiniai failai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Paveikslų failai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Garso failai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Vaizdo failai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Aplankai</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Turinys</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Faile yra:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>Na&amp;udoti reguliarųjį reiškinį</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Savybės</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Failo dydis:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Larger than:</source>
        <translation>Didesnis nei:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Baitų</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="312"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="317"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="325"/>
        <source>Smaller than:</source>
        <translation>Mažesnis nei:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Skirti raidžių dydį</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Ieškoti pakatalogiuose</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Skirti &amp;raidžių dydį</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Paskutinio pakeitimo laikas:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Anksčiau nei:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="402"/>
        <source>Later than:</source>
        <translation>Vėliau nei:</translation>
    </message>
</context>
</TS>
